#[non_exhaustive]pub enum Event {
Delta {
value120: i32,
},
Frame {
time: u32,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Delta
delta movement
Sent whenever the position on a dial changes.
This event carries the wheel delta as multiples or fractions of 120 with each multiple of 120 representing one logical wheel detent. For example, an axis_value120 of 30 is one quarter of a logical wheel step in the positive direction, a value120 of -240 are two logical wheel steps in the negative direction within the same hardware event. See the wl_pointer.axis_value120 for more details.
The value120 must not be zero.
Frame
end of a dial event sequence
Indicates the end of a set of events that represent one logical hardware dial event. A client is expected to accumulate the data in all events within the frame before proceeding.
All zwp_tablet_pad_dial_v2 events before a zwp_tablet_pad_dial_v2.frame event belong logically together.
A zwp_tablet_pad_dial_v2.frame event is sent for every logical event group, even if the group only contains a single zwp_tablet_pad_dial_v2 event. Specifically, a client may get a sequence: delta, frame, delta, frame, etc.